@@ -2,7 +2,7 @@ package Paws::Net::MultiplexCaller;
   use Moose;
   with 'Paws::Net::CallerRole';
 
-  our $VERSION = '0.02';
+  our $VERSION = '0.03';
 
   # TODO: HashRef of things that do Paws::Net::CallerRole
   has caller_for => (is => 'ro', isa => 'HashRef', required => 1);
@@ -18,14 +18,8 @@ package Paws::Net::MultiplexCaller;
 
   sub do_call {
     my ($self, $service, $call_object) = @_;
-    my $result = $self->get_implementation($self->service_from_callobject($call_object))
+    return $self->get_implementation($self->service_from_callobject($call_object))
              ->do_call($service, $call_object);
-
-    if (ref($result) and $result->isa('Paws::Exception')){
-      $result->throw;
-    }
-
-    return $result;
   }
 
   sub caller_to_response {
